@@ -17,18 +17,28 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
+
 def parse_options():
     import sys
     from optparse import OptionParser
     usage = "usage: %prog [options] inputfile"
     parser = OptionParser(usage=usage)
-    parser.add_option("-o", "--stdout", action="store_true", help="print json format to stdout")
-    parser.add_option("-c", "--create", action="store_true", help="create records")
-    parser.add_option("-d", "--delete", action="store_true", help="delete records")
-    parser.add_option("-g", "--retrieve", action="store_true", help="retrieve records")
-    parser.add_option("-s", dest='fqdn', help="specify TonicDNS server")
-    parser.add_option("-u", dest='username', help="TonicDNS username")
-    parser.add_option("-p", dest='password', help="TonicDNS password")
+    parser.add_option("-o", "--stdout", action="store_true",
+                      help="print json format to stdout")
+    parser.add_option("-c", "--create", action="store_true",
+                      help="create records")
+    parser.add_option("-d", "--delete", action="store_true",
+                      help="delete records")
+    parser.add_option("-g", "--retrieve", action="store_true",
+                      help="retrieve records")
+    parser.add_option("-s", dest='fqdn',
+                      help="specify TonicDNS server")
+    parser.add_option("-u", dest='username',
+                      help="TonicDNS username")
+    parser.add_option("-p", dest='password',
+                      help="TonicDNS password")
+    parser.add_option("-P", action='store_true',
+                      help="Prompt for TonicDNS password")
     options, args = parser.parse_args()
 
     if len(args) == 0:
@@ -39,13 +49,16 @@ def parse_options():
 
 
 def main():
-    import os.path, sys, json
-    import converter, tdauth
+    import os.path
+    import sys
+    import json
+    import converter
+    import tdauth
     import processing as p
 
     try:
         options, args = parse_options()
-    except RuntimeError, e:
+    except RuntimeError as e:
         sys.stderr.write("ERROR: %s\n" % e)
         return
 
@@ -66,7 +79,7 @@ def main():
         o.genData(act)
 
         if options.stdout:
-            print json.dumps(o.dict_records, sort_keys=True, indent=2)
+            print(json.dumps(o.dict_records, sort_keys=True, indent=2))
         else:
             dict_records = o.dict_records
             if options.fqdn:
@@ -75,6 +88,9 @@ def main():
                 username = options.username
             if options.password:
                 password = options.password
+            elif options.P:
+                import getpass
+                password = getpass.getpass(prompt='TonicDNS user password: ')
 
             try:
                 a = tdauth.authInfo(username, password, server)
@@ -98,7 +114,7 @@ def main():
                     p.deleteRecords(server, a.token, dict_records)
                     exit
 
-            except UnboundLocalError, e:
+            except UnboundLocalError as e:
                 sys.stderr.write("ERROR: %s\n" % e)
                 return
 
